@@ -25,7 +25,6 @@ static void
 popup_activated(GtkWidget *widget, gpointer data)
 {
  GtkSheet *sheet;
- gint i;
 
  if(!GTK_IS_SHEET(widget->parent->parent)) printf("HOPLA\n"); 
  sheet=GTK_SHEET(widget->parent->parent);
@@ -251,7 +250,7 @@ clipboard_handler(GtkWidget *widget, GdkEventKey *key)
 
   if(key->state & GDK_CONTROL_MASK || key->keyval==GDK_Control_L ||
      key->keyval==GDK_Control_R){
-    if(key->keyval=='c' || key->keyval == 'C' && sheet->state != GTK_STATE_NORMAL){
+    if((key->keyval=='c' || key->keyval == 'C') && sheet->state != GTK_STATE_NORMAL){
             if(GTK_SHEET_IN_CLIP(sheet)) gtk_sheet_unclip_range(sheet);
             gtk_sheet_clip_range(sheet, sheet->range);
     }
@@ -460,7 +459,7 @@ set_cell(GtkWidget *widget, gchar *insert, gint text_legth, gint position,
 {
   char *text;
 
-  if(text=GTK_SHENTRY(GTK_SHEET(widget)->sheet_entry)->text){
+  if((text=GTK_SHENTRY(GTK_SHEET(widget)->sheet_entry)->text)){
                           gtk_entry_set_text(GTK_ENTRY(entry), text);
   }
   GTK_WIDGET_UNSET_FLAGS(entry, GTK_HAS_FOCUS);
@@ -478,7 +477,7 @@ show_sheet_entry(GtkWidget *widget, gpointer data)
 
  sheet=GTK_SHEET(GTK_NOTEBOOK(notebook)->cur_page->child);
 
- if(text=GTK_ENTRY(entry)->text){
+ if((text=GTK_ENTRY(entry)->text)){
    sheet_entry=GTK_SHENTRY(sheet->sheet_entry);
    gtk_shentry_set_text(sheet_entry, text, sheet_entry->justification);
  }
@@ -507,7 +506,7 @@ show_entry(GtkWidget *widget, gpointer data)
  
  if(!GTK_WIDGET_HAS_FOCUS(widget)) return;
 
- if(text=GTK_SHENTRY(widget)->text)
+ if((text=GTK_SHENTRY(widget)->text))
                           gtk_entry_set_text(GTK_ENTRY(entry), text);
 
 }
@@ -515,7 +514,12 @@ show_entry(GtkWidget *widget, gpointer data)
 void 
 activate_sheet_cell(GtkWidget *widget, gint row, gint column, gpointer data)
 {
+  GtkSheet *sheet;
   char cell[100];
+  char *text;
+  GtkSheetCellAttr attributes;
+
+  sheet=GTK_SHEET(widget);
 
   if(GTK_SHEET(widget)->column[column].name)
    sprintf(cell,"  %s:%d  ",GTK_SHEET(widget)->column[column].name, row);
@@ -526,13 +530,24 @@ activate_sheet_cell(GtkWidget *widget, gint row, gint column, gpointer data)
 
   gtk_entry_set_max_length(GTK_ENTRY(entry), 
 	GTK_SHENTRY(GTK_SHEET(widget)->sheet_entry)->text_max_length); 
+
+ if((text=GTK_SHENTRY(GTK_SHEET(widget)->sheet_entry)->text))
+                          gtk_entry_set_text(GTK_ENTRY(entry), text);
+ else
+                          gtk_entry_set_text(GTK_ENTRY(entry), "");
+
+ gtk_sheet_get_attributes(sheet,sheet->active_cell.row,
+                                sheet->active_cell.col, &attributes); 
+
+ gtk_entry_set_editable(GTK_ENTRY(entry), attributes.is_editable);
+
 }
 
 int main(int argc, char *argv[])
 {
   GtkWidget *label; 
-  GtkWidget *label2; 
   gint i;
+
   char *title[]= {"Example 1",
                   "Example 2",
                   "Example 3"};
@@ -603,6 +618,7 @@ int main(int argc, char *argv[])
   build_example3(sheets[2]);
 
   gtk_widget_show(window);
+
   gtk_main();
 
   return(0); 
