@@ -21,6 +21,9 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
+#ifndef __GTK_SHEET_H__
+#define __GTK_SHEET_H__
+
 
 #include <gdk/gdk.h>
 #include <gtk/gtksignal.h>
@@ -29,13 +32,19 @@
 #include <gtk/gtkbutton.h>
 #include <gtk/gtkhscrollbar.h>
 #include <gtk/gtkvscrollbar.h>
+#include <gtk/gtkmain.h>
 #include <gdk/gdkkeysyms.h>
 #include "gtksheetentry.h"
 
+
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 typedef enum{GTK_SHEET_FOREGROUND,
 	     GTK_SHEET_BACKGROUND,
              GTK_SHEET_FONT,
-             GTK_SHEET_FONT_COLOR,
 	     GTK_SHEET_JUSTIFICATION,
 	     GTK_SHEET_BORDER,
              GTK_SHEET_BORDER_COLOR,
@@ -113,7 +122,7 @@ typedef struct _GtkSheetCellBorder     GtkSheetCellBorder;
 struct _GtkSheetButton
 {
   gint state;
-  char *label;
+  gchar *label;
 };
 
 struct _GtkSheetCellBorder
@@ -128,7 +137,7 @@ struct _GtkSheetCellBorder
 
 struct _GtkSheetCellAttr
 {
-  int justification;
+  gint justification;
   GdkFont *font;
   GdkColor foreground;
   GdkColor background;
@@ -140,8 +149,8 @@ struct _GtkSheetCellAttr
 struct _GtkSheetCell
 {
   GdkRectangle area;
-  int row;
-  int col;
+  gint row;
+  gint col;
 
   GtkSheetCellAttr attributes;
 
@@ -151,8 +160,8 @@ struct _GtkSheetCell
 
 struct _GtkSheetRange
 {
-  int row0,col0;
-  int rowi,coli;
+  gint row0,col0;
+  gint rowi,coli;
 };
 
 struct _GtkSheetAttr
@@ -161,7 +170,7 @@ struct _GtkSheetAttr
   GtkSheetAttrType type;
 
   union {
-          int justification;
+          gint justification;
           GdkFont *font;
           GdkColor foreground;
           GdkColor background;
@@ -175,7 +184,7 @@ struct _GtkSheetAttr
 
 struct _GtkSheetRow
 {
- char *name;
+ gchar *name;
  gint height;
  gint top_ypixel;
 
@@ -186,7 +195,7 @@ struct _GtkSheetRow
 
 struct _GtkSheetColumn
 {
- char *name;
+ gchar *name;
  gint width;
  gint left_xpixel;
 
@@ -215,8 +224,8 @@ struct _GtkSheet{
   GtkSheetColumn *column;
 
   /* max number of diplayed cells */
-  int maxrow;
-  int maxcol;
+  gint maxrow;
+  gint maxcol;
 
   /* Displayed range */
 
@@ -226,8 +235,8 @@ struct _GtkSheet{
   GtkSheetCell ***data;
 
   /* max number of allocated cells */
-  int maxallocrow;
-  int maxalloccol;
+  gint maxallocrow;
+  gint maxalloccol;
 
   /* active cell */
   GtkSheetCell active_cell;
@@ -246,7 +255,7 @@ struct _GtkSheet{
   GtkWidget *button;
 
   /* sheet state */
-  int state;
+  gint state;
 
   /* selected range */
   GtkSheetRange range;
@@ -639,3 +648,12 @@ void
 gtk_sheet_get_attributes(GtkSheet *sheet, gint row, gint col, GtkSheetCellAttr *attributes);
 
 
+
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
+#endif /* __GTK_SHEET_H__ */
+
+
